@@ -62,8 +62,8 @@ struct _GnomeEntryPrivate {
 	GList       *items;
 
 	guint16      max_saved;
-	guint32      changed : 1;
-
+	guint        changed : 1;
+	guint        saving_history : 1; 
 	GConfClient *gconf_client;
 	guint        gconf_notify_id;
 };
@@ -347,7 +347,7 @@ gnome_entry_destroy (GtkObject *object)
 		gentry->_priv->gconf_client = NULL;
 	}
 
-	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -368,7 +368,7 @@ gnome_entry_finalize (GObject *object)
 	g_free (gentry->_priv);
 	gentry->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /**
@@ -398,6 +398,15 @@ gnome_entry_history_changed (GConfClient* client,
 
 	gentry = GNOME_ENTRY (user_data);
 
+	/* If we're getting a notification from saving our own
+	 * history, don't reload it.
+	 */
+	if (gentry->_priv->saving_history) {
+		gentry->_priv->saving_history = FALSE;
+
+		return;
+	}
+		
 	gnome_entry_load_history (gentry);
 }
 
@@ -497,11 +506,20 @@ gnome_entry_get_max_saved (GnomeEntry *gentry)
 static char *
 build_gconf_key (GnomeEntry *gentry)
 {
-	return g_strconcat ("/apps/",
-			    gnome_program_get_app_id (gnome_program_get()),
-			    "/history-",
-			    gentry->_priv->history_id,
-			    NULL);
+	gchar *retval;
+	gchar *app_id;
+
+	app_id = gconf_escape_key (gnome_program_get_app_id (gnome_program_get()), -1);
+
+	retval = g_strconcat ("/apps/gnome-settings/",
+			      gnome_program_get_app_id (gnome_program_get()),
+			      "/history-",
+			      gentry->_priv->history_id,
+			      NULL);
+
+	g_free (app_id);
+
+	return retval;
 }
 
 static void
@@ -725,7 +743,6 @@ gnome_entry_save_history (GnomeEntry *gentry)
 	g_assert (gentry->_priv->gconf_client != NULL);
 
 	key = build_gconf_key (gentry);
-
 	gconf_items = NULL;
 
 	for (n = 0, items = gentry->_priv->items;
@@ -739,6 +756,7 @@ gnome_entry_save_history (GnomeEntry *gentry)
 	}
 
 	/* Save the list */
+	gentry->_priv->saving_history = TRUE;
 	gconf_client_set_list (gentry->_priv->gconf_client, key, GCONF_VALUE_STRING, gconf_items, NULL);
 	
 	g_free (key);
